MINIMUM_STORAGE_BALANCE = 1_250_000_000_000_000_000_000
ACCOUNT_INIT_BALANCE = 23_467_413_599_927_650_444_124

DEFAULT_TOKEN_DECIMAL = 24
BASE_TEN = 10

CONTRACT_INITIAL_BALANCE = 2781350099999999300000000
CONTRACT_ATTACHED_GAS = 200000000000000
